==> LinHES-system-8.6.1-1-x86_64.pkg.tar.xz: usr/LH/bin/linhes_update2.sh <==
#!/bin/bash
#Called from LinHES Service Menu Updates Available Menu

if [[ "$1" = "install" ]]
then
    msg_client.py --msg "Updating...|middle" --timeout 600 --tag "Updating"
    sudo pacman -Su --force --noconfirm
    msg_client.py --clear --tag "Updating"
    msg_client.py --kill
    msg_client.py --msg "Updates complete.\nReturning to Main Menu.|middle"
    if grep linux /tmp/to_be_upgraded || grep nvidia /tmp/to_be_upgraded
    then
        msg_client.py --msg "Updates require a reboot.|middle"
    fi
else
    msg_client.py --msg "Updates canceled.|middle"
fi

sudo rm -fr /tmp/to_be_upgraded

if grep -q Updates\ Available /usr/share/mythtv/themes/defaultmenu/linhes.xml
then
    mv /usr/share/mythtv/themes/defaultmenu/linhes.xml /tmp/linhes.xml.tmp
    sed -e '/\#UpdatesAv/,/\#UpdatesAv/d' < /tmp/linhes.xml.tmp > /usr/share/mythtv/themes/defaultmenu/linhes.xml
    mv /usr/share/mythtv/themes/defaultmenu/linhes.xml /tmp
    grep -va '/mythmenu' /tmp/linhes.xml > /tmp/linhes.xml.tmp
    echo "<!--#Check for updates-->" >> /tmp/linhes.xml.tmp
    echo "   <button>" >> /tmp/linhes.xml.tmp
    echo "     <type>UPGRADE</type>" >> /tmp/linhes.xml.tmp
    echo "     <text>Update LinHES</text>" >> /tmp/linhes.xml.tmp
    echo "     <description>Update the LinHES system</description>" >> /tmp/linhes.xml.tmp
    echo "     <action>MENU update.xml</action>" >> /tmp/linhes.xml.tmp
    echo "   </button>" >> /tmp/linhes.xml.tmp
    echo "<!--#Check for updates-->" >> /tmp/linhes.xml.tmp
    echo "" >> /tmp/linhes.xml.tmp
    echo "</mythmenu>" >> /tmp/linhes.xml.tmp
    mv /tmp/linhes.xml.tmp /usr/share/mythtv/themes/defaultmenu/linhes.xml
fi

#hide LinHES update message on main menu
sudo sed -i '/LinHES UPDATE MESSAGE/c\        <!--LinHES UPDATE MESSAGE' /usr/share/mythtv/themes/LinHES/menu-ui.xml

#reload mythfrontend
killall mythfrontend

==> LinHES-system-8.7.0-2-x86_64.pkg.tar.xz: usr/LH/bin/linhes_update2.sh <==
#!/bin/bash
#Called from LinHES Service Menu Updates Available Menu

if [[ "$1" = "install" ]]
then
    msg_client.py --msg "Updating...|middle" --timeout 600 --tag "Updating"
    sudo pacman -Su --noconfirm
    msg_client.py --clear --tag "Updating"
    msg_client.py --kill
    msg_client.py --msg "Updates complete.\nReturning to Main Menu.|middle"
    if grep linux /tmp/to_be_upgraded || grep nvidia /tmp/to_be_upgraded
    then
        msg_client.py --msg "Updates require a reboot.|middle"
    fi
else
    msg_client.py --msg "Updates canceled.|middle"
fi

sudo rm -fr /tmp/to_be_upgraded

if grep -q Updates\ Available /usr/share/mythtv/themes/defaultmenu/linhes.xml
then
    mv /usr/share/mythtv/themes/defaultmenu/linhes.xml /tmp/linhes.xml.tmp
    sed -e '/\#UpdatesAv/,/\#UpdatesAv/d' < /tmp/linhes.xml.tmp > /usr/share/mythtv/themes/defaultmenu/linhes.xml
    mv /usr/share/mythtv/themes/defaultmenu/linhes.xml /tmp
    grep -va '/mythmenu' /tmp/linhes.xml > /tmp/linhes.xml.tmp
    echo "<!--#Check for updates-->" >> /tmp/linhes.xml.tmp
    echo "   <button>" >> /tmp/linhes.xml.tmp
    echo "     <type>UPGRADE</type>" >> /tmp/linhes.xml.tmp
    echo "     <text>Update LinHES</text>" >> /tmp/linhes.xml.tmp
    echo "     <description>Update the LinHES system</description>" >> /tmp/linhes.xml.tmp
    echo "     <action>MENU update.xml</action>" >> /tmp/linhes.xml.tmp
    echo "   </button>" >> /tmp/linhes.xml.tmp
    echo "<!--#Check for updates-->" >> /tmp/linhes.xml.tmp
    echo "" >> /tmp/linhes.xml.tmp
    echo "</mythmenu>" >> /tmp/linhes.xml.tmp
    mv /tmp/linhes.xml.tmp /usr/share/mythtv/themes/defaultmenu/linhes.xml
fi

#hide LinHES update message on main menu
sudo sed -i '/LinHES UPDATE MESSAGE/c\        <!--LinHES UPDATE MESSAGE' /usr/share/mythtv/themes/LinHES/menu-ui.xml

#reload mythfrontend
killall mythfrontend
